@@ -22,31 +22,33 @@ from Qt import QtWidgets
 class HandlerBase(object):
     pass
 
+
 class ItemMeta(type):
-    
-    def __getitem__(cls,item):
+    def __getitem__(cls, item):
         cls.item = item
         return cls
-class ItemConstructor(HandlerBase,six.with_metaclass(ItemMeta)):
-    
+
+
+class ItemConstructor(HandlerBase, six.with_metaclass(ItemMeta)):
     def __init__(self, *args, **kwargs):
         self.args = args
         self.kwargs = kwargs
-    
+
     def __rrshift__(self, item_data):
         # binding = Binding._inst_.pop()
-        
+
         # NOTE trace lamda function
         filters = self.kwargs.pop("__filters__", [i for i in range(len(item_data))])
         if callable(filters):
             # NOTE make sure handle list data
             filters = [item_data.index(d) for d in filters(item_data)]
 
-        layout = self.kwargs.pop("__layout__", self.item.__layout__)
-        binder_name = self.kwargs.pop("__binder__", self.item.__binder__)
-        if not hasattr(layout,'__items__'):
+        layout = self.kwargs.pop("__layout__")
+        binder_name = self.kwargs.pop("__binder__")
+
+        if not hasattr(layout, "__items__"):
             layout.__items__ = []
-            
+
         for i, data in enumerate(item_data):
             widget = layout.__items__ >> ListGet(i)
             if not widget:
@@ -117,4 +119,4 @@ class Anim(HandlerBase):
 
     def __rrshift__(self, binding):
         Binding._inst_
-        return binding
\ No newline at end of file
+        return binding
