@@ -53,9 +53,10 @@ def get_method_name(method):
         count = method.parameterNames()
     return byte2str(name), count
 
+
 for name, member in qt_dict.items():
     # NOTE filter qt related func
-    if not hasattr(member, "staticMetaObject"):
+    if name == "QtGui.QMatrix" or not hasattr(member, "staticMetaObject"):
         continue
     meta_obj = getattr(member, "staticMetaObject")
     data = CONFIG.get(name, {})
@@ -65,6 +66,14 @@ for name, member in qt_dict.items():
             if method_name.startswith("set"):
                 _HOOKS_REL[method_name.lower()] = method_name
 
+    # for i in range(meta_obj.methodCount()):
+    #     method = meta_obj.method(i)
+    #     method_name, count = get_method_name(method)
+    #     if count and method.methodType() != QtCore.QMetaMethod.Signal:
+    #         if hasattr(member, method_name):
+    #             HOOKS[name][method_name] = {}
+    #             _HOOKS_REL[name][method_name.lower()] = method_name
+
     # NOTE auto bind updater
     for i in range(meta_obj.propertyCount()):
         property = meta_obj.property(i)
@@ -97,7 +106,7 @@ class FuncHook(object):
     @classmethod
     def auto_dump(cls, binding):
         """auto dump for two way binding"""
-        
+
         from .constant import AUTO_DUMP
 
         binder = binding.__binder__
@@ -115,13 +124,13 @@ class FuncHook(object):
             return val + args[1:]
         else:
             return (val,) + args[1:]
-    
+
     def __init__(self, options):
         self.options = options
 
     def __call__(cls, func):
         @six.wraps(func)
-        def wrapper(self,*args, **kwargs):
+        def wrapper(self, *args, **kwargs):
             if len(args) != 1:
                 return func(self, *args, **kwargs)
 
@@ -163,7 +172,9 @@ class FuncHook(object):
                 ):
                     updater = getattr(self, updater)
                     updater.connect(
-                        cls.fix_cursor_position(lambda *args: binding.set(getter()), self)
+                        cls.fix_cursor_position(
+                            lambda *args: binding.set(getter()), self
+                        )
                     )
                     binding = Binding._trace_list_.pop()
                     QtCore.QTimer.singleShot(0, partial(cls.auto_dump, binding))
@@ -183,4 +194,3 @@ def hook_initialize(hooks):
         for setter, options in setters.items():
             func = getattr(widget, setter)
             setattr(widget, setter, FuncHook(options)(func))
-            
\ No newline at end of file
